@@ -3,6 +3,19 @@ from datetime import datetime, timedelta
 
 
 class Request:
+    """
+    A Request to fetch dataframes from Wizata App.
+
+    To execute the request please use a DS API client.
+
+    :ivar equipments: List of Equipments containing Digital Twin item and datapoints to fetch.
+    :ivar start: Datetime defining beginning of period.
+    :ivar end: Datetime defining end of period.
+    :ivar aggregation: Aggregation method to fetch, accept "mean" and "stddev".
+    :ivar interval: Interval in seconds between each aggregation.
+    :ivar filters: Filter to apply on the query (not yet fully implemented).
+    :ivar connections: Connections rules between equipment to align data in time (not yet fully implemented).
+    """
 
     def __init__(self):
         self.function = None
@@ -56,7 +69,12 @@ class Request:
             raise TypeError("date is not a valid datetime")
 
     # add datapoints without any reference to an equipment
-    def add_datapoints(self, datapoints, shift=0):
+    def add_datapoints(self, datapoints, shift: int = 0):
+        """
+        Add datapoints to fetch without defining its equipments.
+        :param datapoints: List(str) of datapoints to fetch identified by Hardware ID.
+        :param shift: Shift to apply in seconds on timestamp, by default 0.
+        """
         self.equipments.append({
             "id": None,
             "datapoints": list(datapoints),
@@ -64,6 +82,12 @@ class Request:
         })
 
     def add_equipment(self, equipment_id: uuid.UUID, datapoints, shift=0):
+        """
+        Add datapoints to fetch with a Digital Twin ID identification.
+        :param equipment_id: UUID of the Digital Twin ID to which the datapoints are linked.
+        :param datapoints: List(str) of datapoints to fetch identified by Hardware ID.
+        :param shift: Shift to apply in seconds on timestamp, by default 0.
+        """
         if not isinstance(equipment_id, uuid.UUID):
             raise TypeError("equipment_id must be of type uuid.UUID")
         for equipment in self.equipments:
@@ -77,6 +101,10 @@ class Request:
 
     # attempt to remove equipment from the query if exists
     def remove_equipment(self, equipment_id: uuid.UUID):
+        """
+        Remove an equipment from the list including all its listed datapoints.
+        :param equipment_id: UUID of the Digital Twin item.
+        """
         if equipment_id is not None and not isinstance(equipment_id, uuid.UUID):
             raise TypeError("equipment_id must be None or of type uuid.UUID")
         found = None
@@ -90,8 +118,7 @@ class Request:
         """
         Specifies aggregation properties
         :param method: 'mean' or 'stddev'
-        :param interval:  interval in ms (will be stored in seconds)
-        :return:
+        :param interval: interval in ms (will be stored in seconds)
         """
         self.aggregation = method
         self.interval = int(interval) / 1000
@@ -124,6 +151,11 @@ class Request:
         return obj
 
     def from_json(self, json_data):
+        """
+        load a request based on dict from a JSON file.
+
+        :param json_data: JSON formatted dictionnary object representing a query.
+        """
         if "name" in json_data.keys():
             self.name = json_data["name"]
 
