@@ -158,26 +158,17 @@ class WizataDSAPIClient:
         else:
             raise TypeError("Type not supported.")
 
-    def get(self, obj):
+    def get(self, obj=None, script_name=None):
         """
         get full content of an object identified with is id.
 
         :param obj: object of a supported entity with at list its id
+        :param script_name: alternatively you can use a function name to get a script
         :return: object completed with all properties on server.
         """
-        if isinstance(obj, MLModel):
+        if script_name is not None:
             response = requests.request("GET",
-                                        self.__url() + "mlmodels/" + str(obj.model_id) + "/",
-                                        headers=self.__header()
-                                        )
-            if response.status_code == 200:
-                mlmodel_bytes = response.content
-                return pickle.loads(mlmodel_bytes)
-            else:
-                raise self.__raise_error(response)
-        elif isinstance(obj, Script):
-            response = requests.request("GET",
-                                        self.__url() + "scripts/" + str(obj.script_id) + "/",
+                                        self.__url() + "scripts/" + str(script_name) + "/",
                                         headers=self.__header()
                                         )
             if response.status_code == 200:
@@ -185,36 +176,57 @@ class WizataDSAPIClient:
                 return dill.loads(script_bytes)
             else:
                 raise self.__raise_error(response)
-        elif isinstance(obj, Plot):
-            response = requests.request("GET",
-                                        self.__url() + "plots/" + str(obj.plot_id) + "/",
-                                        headers=self.__header()
-                                        )
-            if response.status_code == 200:
-                obj.from_json(response.json())
-                return obj
+        if obj is not None:
+            if isinstance(obj, MLModel):
+                response = requests.request("GET",
+                                            self.__url() + "mlmodels/" + str(obj.model_id) + "/",
+                                            headers=self.__header()
+                                            )
+                if response.status_code == 200:
+                    mlmodel_bytes = response.content
+                    return pickle.loads(mlmodel_bytes)
+                else:
+                    raise self.__raise_error(response)
+            elif isinstance(obj, Script):
+                response = requests.request("GET",
+                                            self.__url() + "scripts/" + str(obj.name) + "/",
+                                            headers=self.__header()
+                                            )
+                if response.status_code == 200:
+                    script_bytes = response.content
+                    return dill.loads(script_bytes)
+                else:
+                    raise self.__raise_error(response)
+            elif isinstance(obj, Plot):
+                response = requests.request("GET",
+                                            self.__url() + "plots/" + str(obj.plot_id) + "/",
+                                            headers=self.__header()
+                                            )
+                if response.status_code == 200:
+                    obj.from_json(response.json())
+                    return obj
+                else:
+                    raise self.__raise_error(response)
+            elif isinstance(obj, DSDataFrame):
+                response = requests.request("GET",
+                                            self.__url() + "dataframes/" + str(obj.df_id) + "/",
+                                            headers=self.__header()
+                                            )
+                if response.status_code == 200:
+                    df_bytes = response.content
+                    return pickle.loads(df_bytes)
+                else:
+                    raise self.__raise_error(response)
+            elif isinstance(obj, Request):
+                response = requests.request("POST", self.__url() + "execute/data",
+                                            headers=self.__header(),
+                                            data=json.dumps(obj.prepare(), cls=DSAPIEncoder))
+                if response.status_code == 200:
+                    return pickle.loads(response.content)
+                else:
+                    raise self.__raise_error(response)
             else:
-                raise self.__raise_error(response)
-        elif isinstance(obj, DSDataFrame):
-            response = requests.request("GET",
-                                        self.__url() + "dataframes/" + str(obj.df_id) + "/",
-                                        headers=self.__header()
-                                        )
-            if response.status_code == 200:
-                df_bytes = response.content
-                return pickle.loads(df_bytes)
-            else:
-                raise self.__raise_error(response)
-        elif isinstance(obj, Request):
-            response = requests.request("POST", self.__url() + "execute/data",
-                                        headers=self.__header(),
-                                        data=json.dumps(obj.prepare(), cls=DSAPIEncoder))
-            if response.status_code == 200:
-                return pickle.loads(response.content)
-            else:
-                raise self.__raise_error(response)
-        else:
-            raise TypeError("Type not supported.")
+                raise TypeError("Type not supported.")
 
     def create(self, obj):
         """
@@ -253,6 +265,26 @@ class WizataDSAPIClient:
         else:
             raise TypeError("Type not supported.")
 
+    def upsert(self, obj):
+        """
+        upsert on object on the server
+        work with Script using the technical name of the function
+
+        :param obj: object to upsert on the server
+        :return: ID of the object created or updated
+        """
+
+        if isinstance(obj, Script):
+            response = requests.put(self.__url() + "scripts/",
+                                    headers=self.__header(),
+                                    data=dill.dumps(obj))
+            if response.status_code == 200:
+                return obj.script_id
+            else:
+                raise self.__raise_error(response)
+        else:
+            raise TypeError("Type not supported.")
+
     def delete(self, obj):
         """
         delete an object on the server
@@ -306,7 +338,7 @@ class WizataDSAPIClient:
         :param execution: Execution to execute on the server with configuration (Request, Script, ML Model, ...)
         :param request: Request to use to generate a dataframe
         :param dataframe: dataframe to be used as input (pandas or DS API type)
-        :param script: Script to be executed (accept Script, string(id) or uuid)
+        :param script: Script to be executed (accept Script,uuid or script function name)
         :param ml_model: MLModel to be executed (accept MLModel, ml_model(id) or uuid)
         :param isAnomalyDetection: set to true to execute automatic anomaly detection
         :param function: set to name of a built-in function to execute it
@@ -326,7 +358,7 @@ class WizataDSAPIClient:
             if isinstance(script, uuid.UUID):
                 execution.script = Script(script)
             elif isinstance(script, str):
-                execution.script = Script(uuid.UUID(script))
+                execution.script = self.get(script_name=script)
             elif isinstance(script, Script):
                 execution.script = script
         if ml_model is not None:
@@ -356,7 +388,7 @@ class WizataDSAPIClient:
                 if "models" in obj.keys():
                     for mlmodel in obj["models"]:
                         execution.models.append(self.get(MLModel(model_id=mlmodel["id"])))
-                if "resultDataframe" in obj.keys():
+                if "resultDataframe" in obj.keys() and obj["resultDataframe"]["id"] is not None:
                     execution.output_ds_dataframe = self.get(DSDataFrame(df_id=obj["resultDataframe"]["id"]))
                 return execution
             else:
@@ -364,21 +396,44 @@ class WizataDSAPIClient:
         else:
             raise TypeError("No execution have been loaded from parameters.")
 
-    def validate(self, obj: Execution) -> Script:
+    def validate(self,
+                 execution: Execution = None,
+                 request: Request = None,
+                 dataframe=None,
+                 script=None) -> Script:
         """
         run an execution to validate the script used.
         Do not store anything on the DS API nor return anything.
         In case of error, set the Script as invalid.
 
-        :param obj: Execution to validate - must contains a dataframe or a query and a script
+        :param execution: Execution to validate - must contain a dataframe or a query and a script
+        :param request: Request to use to generate a dataframe
+        :param dataframe: dataframe to be used as input (pandas or DS API type)
+        :param script: Script to be executed (accept Script, string(id) or uuid)
         :return: validated script properties (do not use update or it will invalidate the script)
         """
-        if isinstance(obj, Execution):
-            if obj.script is None:
+        if execution is None:
+            execution = Execution()
+        if request is not None:
+            execution.request = request
+        if dataframe is not None:
+            if isinstance(dataframe, pandas.DataFrame):
+                execution.dataframe = dataframe
+            elif isinstance(dataframe, DSDataFrame):
+                execution.input_ds_dataframe = dataframe
+        if script is not None:
+            if isinstance(script, uuid.UUID):
+                execution.script = Script(script)
+            elif isinstance(script, str):
+                execution.script = self.get(script_name=script)
+            elif isinstance(script, Script):
+                execution.script = script
+        if isinstance(execution, Execution):
+            if execution.script is None:
                 raise ValueError("Execution must contains at least a Script.")
             response = requests.post(self.__url() + "execute/validate",
                                      headers=self.__header(),
-                                     data=json.dumps(obj.to_json(), cls=DSAPIEncoder))
+                                     data=json.dumps(execution.to_json(), cls=DSAPIEncoder))
             if response.status_code == 200:
                 response_script = Script()
                 response_script.from_json(response.json())
@@ -425,7 +480,7 @@ class WizataDSAPIClient:
             if isinstance(script, uuid.UUID):
                 execution.script = Script(script)
             elif isinstance(script, str):
-                execution.script = Script(uuid.UUID(script))
+                execution.script = self.get(script_name=script)
             elif isinstance(script, Script):
                 execution.script = script
         if ml_model is not None:
